BOOST_PLAT platform macros

### `BOOST_PLAT` platform macros

##### `BOOST_PLAT_MINGW`

MinGW platform. Version number available as major, minor, and patch.

Symbol | Version
--- | ---
`__MINGW32__` | detection
`__MINGW64__` | detection
`__MINGW64_VERSION_MAJOR`, `__MINGW64_VERSION_MINOR` | V.R.0
`__MINGW32_VERSION_MAJOR`, `__MINGW32_VERSION_MINOR` | V.R.0

##### `BOOST_PLAT_WINDOWS_DESKTOP`

Symbol | Version
--- | ---
`!WINAPI_FAMILY` | detection
`WINAPI_FAMILY == WINAPI_FAMILY_DESKTOP_APP` | detection

##### `BOOST_PLAT_WINDOWS_PHONE`

Symbol | Version
--- | ---
`WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP` | detection

##### `BOOST_PLAT_WINDOWS_RUNTIME`

Symbol | Version
--- | ---
`WINAPI_FAMILY == WINAPI_FAMILY_APP` | detection
`WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP` | detection

##### `BOOST_PLAT_WINDOWS_STORE`

Symbol | Version
--- | ---
`WINAPI_FAMILY == WINAPI_FAMILY_APP` | detection